@@ -1,4 +1,5 @@
 """Common functionality shared across multiple type of runs."""
+
 from __future__ import annotations
 
 import logging
@@ -38,7 +39,7 @@ class SkipMissingInterpreterAction(Action):
         option_string: str | None = None,  # noqa: ARG002
     ) -> None:
         value = "true" if values is None else values
-        if value not in ("config", "true", "false"):
+        if value not in {"config", "true", "false"}:
             raise ArgumentError(self, f"value must be 'config', 'true', or 'false' (got {value!r})")
         setattr(namespace, self.dest, value)
 
@@ -63,7 +64,7 @@ class InstallPackageAction(Action):
 
 def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:  # noqa: C901
     # mode can be one of: run, run-parallel, legacy, devenv, config
-    if mode not in ("config", "depends"):
+    if mode not in {"config", "depends"}:
         parser.add_argument(
             "--result-json",
             dest="result_json",
@@ -72,7 +73,7 @@ def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:  # noqa: C9
             default=None,
             help="write a JSON file with detailed information about all commands and results involved",
         )
-    if mode not in ("devenv", "depends"):
+    if mode not in {"devenv", "depends"}:
         parser.add_argument(
             "-s",
             "--skip-missing-interpreters",
@@ -82,7 +83,7 @@ def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:  # noqa: C9
             action=SkipMissingInterpreterAction,
             help="don't fail tests for missing interpreters: {config,true,false} choice",
         )
-    if mode not in ("devenv", "config", "depends"):
+    if mode not in {"devenv", "config", "depends"}:
         parser.add_argument(
             "-n",
             "--notest",
@@ -106,14 +107,14 @@ def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:  # noqa: C9
             action=InstallPackageAction,
             dest="install_pkg",
         )
-    if mode not in ("devenv", "depends"):
+    if mode not in {"devenv", "depends"}:
         parser.add_argument(
             "--develop",
             action="store_true",
             help="install package in development mode",
             dest="develop",
         )
-    if mode not in ("depends",):
+    if mode != "depends":
 
         class SeedAction(Action):
             def __call__(
@@ -158,7 +159,7 @@ def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:  # noqa: C9
         help="for Python discovery first try the Python executables under these paths",
         default=[],
     )
-    if mode not in ("depends",):
+    if mode != "depends":
         parser.add_argument(
             "--no-recreate-pkg",
             dest="no_recreate_pkg",
@@ -178,7 +179,7 @@ def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:  # noqa: C9
             dest="list_dependencies",
             help="never list the dependencies installed during environment setup",
         )
-    if mode not in ("devenv", "config", "depends"):
+    if mode not in {"devenv", "config", "depends"}:
         parser.add_argument(
             "--skip-pkg-install",
             dest="skip_pkg_install",
@@ -255,9 +256,9 @@ def execute(state: State, max_workers: int | None, has_spinner: bool, live: bool
             interrupt.set()
             # cancel in reverse order to not allow submitting new jobs as we cancel running ones
             for future, tox_env in reversed(list(future_to_env.items())):
-                cancelled = future.cancel()
-                # if cannot be cancelled and not done -> still runs
-                if cancelled is False and not future.done():  # pragma: no branch
+                canceled = future.cancel()
+                # if cannot be canceled and not done -> still runs
+                if canceled is False and not future.done():  # pragma: no branch
                     tox_env.interrupt()
             done.wait()
             # workaround for https://bugs.python.org/issue45274
@@ -309,7 +310,7 @@ def _queue_and_wait(  # noqa: C901, PLR0913, PLR0915
     spinner: ToxSpinner,
     live: bool,  # noqa: FBT001
 ) -> None:
-    try:
+    try:  # noqa: PLR1702
         options = state._options  # noqa: SLF001
         with spinner:
             max_workers = len(to_run_list) if max_workers is None else max_workers
