@@ -4,6 +4,7 @@ import logging
 import re
 from collections import Counter
 from dataclasses import dataclass
+from difflib import get_close_matches
 from itertools import chain
 from typing import TYPE_CHECKING, Dict, Iterable, Iterator, List, cast
 
@@ -25,8 +26,25 @@ if TYPE_CHECKING:
 LOGGER = logging.getLogger(__name__)
 
 
-class CliEnv:
-    """CLI tox env selection."""
+class CliEnv:  # noqa: PLW1641
+    """A `CliEnv` is the user's selection of tox test environments, usually supplied via the ``-e`` command-line option
+    or in a TOML file (typically ``env_list`` in ``tox.ini``). It may be treated as a sequence if it's not a "default"
+    or "all" selection.
+
+    It is in one of three forms:
+
+    - A list of specific environments, instantiated with a string that is a comma-separated list of the environment
+      names. (These may have spaces on either side of the commas which are removed.) As a sequence this will be a
+      sequence of those names.
+
+    - "ALL" which is all environments defined by the tox configuration. This is instantiated with ``ALL`` either
+      alone or as any element of a comma-separated list; any other environment names are ignored. `is_all()` will be
+      true and as a sequence it will be empty. This prints in string representation as ``ALL``.
+
+    - The default environments as chosen by tox configuration. This is instantiated with `None` as the parameter,
+      `is_default_list()` will be true, and as a sequence this will be empty. This prints in string representation
+      as ``<env_list>``.
+    """
 
     def __init__(self, value: None | list[str] | str = None) -> None:
         if isinstance(value, str):
@@ -38,6 +56,7 @@ class CliEnv:
             yield from self._names
 
     def __bool__(self) -> bool:
+        """A `CliEnv` is `True` if it's not the default set of environments."""
         return bool(self._names)
 
     def __str__(self) -> str:
@@ -117,6 +136,10 @@ class _ToxEnvInfo:
     package_skip: tuple[str, Skip] | None = None  #: if set the creation of the packaging environment failed
 
 
+_DYNAMIC_ENV_FACTORS = re.compile(r"(pypy|py|cython|)((\d(\.\d+(\.\d+)?)?)|\d+)?")
+_PY_PRE_RELEASE_FACTOR = re.compile(r"alpha|beta|rc\.\d+")
+
+
 class EnvSelector:
     def __init__(self, state: State) -> None:
         # needs core to load the default tox environment list
@@ -127,7 +150,7 @@ class EnvSelector:
         self._state = state
         self._defined_envs_: None | dict[str, _ToxEnvInfo] = None
         self._pkg_env_counter: Counter[str] = Counter()
-        from tox.plugin.manager import MANAGER
+        from tox.plugin.manager import MANAGER  # noqa: PLC0415
 
         self._manager = MANAGER
         self._log_handler = self._state._options.log_handler  # noqa: SLF001
@@ -152,21 +175,50 @@ class EnvSelector:
         elif self._cli_envs.is_all:
             everything_active = True
         else:
-            cli_envs_not_in_config = set(self._cli_envs) - set(self._state.conf)
-            if cli_envs_not_in_config:
-                # allow cli_envs matching ".pkg" and starting with "py" to be implicitly created.
-                disallowed_cli_envs = [
-                    env for env in cli_envs_not_in_config if not env.startswith("py") and env not in (".pkg",)
-                ]
-                if disallowed_cli_envs:
-                    msg = f"provided environments not found in configuration file: {disallowed_cli_envs}"
-                    raise HandledError(msg)
+            self._ensure_envs_valid()
             yield self._cli_envs, True
         yield self._state.conf, everything_active
         label_envs = dict.fromkeys(chain.from_iterable(self._state.conf.core["labels"].values()))
         if label_envs:
             yield label_envs.keys(), False
 
+    def _ensure_envs_valid(self) -> None:
+        valid_factors = set(chain.from_iterable(env.split("-") for env in self._state.conf))
+        valid_factors.add(".pkg")  # packaging factor
+        invalid_envs: dict[str, str | None] = {}
+        for env in self._cli_envs or []:
+            if env.startswith(".pkg_external"):  # external package
+                continue
+            factors: dict[str, str | None] = dict.fromkeys(env.split("-"))
+            found_factors: set[str] = set()
+            for factor in factors:
+                if (
+                    _DYNAMIC_ENV_FACTORS.fullmatch(factor)
+                    or _PY_PRE_RELEASE_FACTOR.fullmatch(factor)
+                    or factor in valid_factors
+                ):
+                    found_factors.add(factor)
+                else:
+                    closest = get_close_matches(factor, valid_factors, n=1)
+                    factors[factor] = closest[0] if closest else None
+            if set(factors) - found_factors:
+                invalid_envs[env] = (
+                    None
+                    if any(i is None for i in factors.values())
+                    else "-".join(cast(Iterable[str], factors.values()))
+                )
+        if invalid_envs:
+            msg = "provided environments not found in configuration file:\n"
+            first = True
+            for env, suggestion in invalid_envs.items():
+                if not first:
+                    msg += "\n"
+                first = False
+                msg += env
+                if suggestion:
+                    msg += f" - did you mean {suggestion}?"
+            raise HandledError(msg)
+
     def _env_name_to_active(self) -> dict[str, bool]:
         env_name_to_active_map = {}
         for a_collection, is_active in self._collect_names():
@@ -195,7 +247,7 @@ class EnvSelector:
         # we need to redefine it, e.g. when it shows up in config as [testenv:.package] and afterwards by a run env is
         # marked as package_env.
 
-        if self._defined_envs_ is None:
+        if self._defined_envs_ is None:  # noqa: PLR1702
             self._defined_envs_ = {}
             failed: dict[str, Exception] = {}
             env_name_to_active = self._env_name_to_active()
@@ -352,7 +404,7 @@ class EnvSelector:
         """
         return self._defined_envs[item].env
 
-    def iter(  # noqa: A003
+    def iter(
         self,
         *,
         only_active: bool = True,
@@ -390,7 +442,7 @@ class EnvSelector:
 
 
 __all__ = [
-    "register_env_select_flags",
-    "EnvSelector",
     "CliEnv",
+    "EnvSelector",
+    "register_env_select_flags",
 ]
