@@ -1,4 +1,5 @@
 """Adapted from the pip code base."""
+
 from __future__ import annotations
 
 import os
@@ -20,7 +21,7 @@ from .util import VCS, get_url_scheme, is_url, url_to_path
 # Matches environment variable-style values in '${MY_VARIABLE_1}' with the variable name consisting of only uppercase
 # letters, digits or the '_' (underscore). This follows the POSIX standard defined in IEEE Std 1003.1, 2013 Edition.
 _ENV_VAR_RE = re.compile(r"(?P<var>\${(?P<name>[A-Z0-9_]+)})")
-_SCHEME_RE = re.compile(r"^(http|https|file):", re.I)
+_SCHEME_RE = re.compile(r"^(http|https|file):", re.IGNORECASE)
 _COMMENT_RE = re.compile(r"(^|\s+)#.*$")
 # https://www.python.org/dev/peps/pep-0508/#extras
 _EXTRA_PATH = re.compile(r"(.*)\[([-._,\sa-zA-Z0-9]*)]")
@@ -176,8 +177,7 @@ class RequirementsFile:
             self._extend_parser(self._parser_private)
         return self._parser_private
 
-    def _extend_parser(self, parser: ArgumentParser) -> None:
-        ...
+    def _extend_parser(self, parser: ArgumentParser) -> None: ...
 
     def _ensure_requirements_parsed(self) -> None:
         if self._requirements is None:
@@ -197,7 +197,7 @@ class RequirementsFile:
         result.sort(key=self._key_func)
         return result
 
-    def _key_func(self, line: ParsedRequirement) -> tuple[int, tuple[int, str, str]]:
+    def _key_func(self, line: ParsedRequirement) -> tuple[int, tuple[int, str, str]]:  # noqa: PLR6301
         of_type = {Requirement: 0, Path: 1, str: 2}[type(line.requirement)]
         between = of_type, str(line.requirement).lower(), str(line.options)
         if "is_constraint" in line.options:
@@ -244,7 +244,7 @@ class RequirementsFile:
         :param url:         File path or url.
         """
         scheme = get_url_scheme(url)
-        if scheme in ["http", "https"]:
+        if scheme in {"http", "https"}:
             with urlopen(url) as response:  # noqa: S310
                 return self._read_decode(response)
         elif scheme == "file":
@@ -296,7 +296,7 @@ class RequirementsFile:
             req_options["hash"] = hash_values
         return ParsedRequirement(line.requirement, req_options, line.filename, line.lineno)
 
-    def _merge_option_line(  # noqa: C901, PLR0912, PLR0915
+    def _merge_option_line(  # noqa: C901, PLR0912, PLR0915, PLR6301
         self,
         base_opt: Namespace,
         opt: Namespace,
@@ -320,7 +320,7 @@ class RequirementsFile:
                 base_opt.features_enabled = []
             for feature in opt.features_enabled:
                 if feature not in base_opt.features_enabled:
-                    base_opt.features_enabled.append(feature)  # noqa: PERF401
+                    base_opt.features_enabled.append(feature)
             base_opt.features_enabled.sort()
         if opt.index_url:
             if getattr(base_opt, "index_url", []):
@@ -449,7 +449,7 @@ class RequirementsFile:
             self._as_root_args = result
         return self._as_root_args
 
-    def _option_to_args(self, opt: Namespace) -> list[str]:  # noqa: C901, PLR0912
+    def _option_to_args(self, opt: Namespace) -> list[str]:  # noqa: C901, PLR0912, PLR6301
         result: list[str] = []
         for req in getattr(opt, "requirements", []):
             result.extend(("-r", req))
@@ -484,7 +484,7 @@ class RequirementsFile:
 
 
 __all__ = (
-    "RequirementsFile",
-    "ReqFileLines",
     "ParsedRequirement",
+    "ReqFileLines",
+    "RequirementsFile",
 )
