@@ -1,9 +1,8 @@
 from __future__ import annotations
 
 import glob
-import shutil
-import sys
 import tarfile
+from abc import ABC
 from functools import partial
 from io import TextIOWrapper
 from pathlib import Path
@@ -34,21 +33,14 @@ if TYPE_CHECKING:
     from tox.tox_env.register import ToxEnvRegister
     from tox.tox_env.runner import RunToxEnv
 
-if sys.version_info >= (3, 8):  # pragma: no cover (py38+)
-    from importlib.metadata import Distribution
-else:  # pragma: no cover (py38+)
-    from importlib_metadata import Distribution
+from importlib.metadata import Distribution
 
 
-class VirtualEnvCmdBuilder(PythonPackageToxEnv, VirtualEnv):
+class VenvCmdBuilder(PythonPackageToxEnv, ABC):
     def __init__(self, create_args: ToxEnvCreateArgs) -> None:
         super().__init__(create_args)
         self._sdist_meta_tox_env: Pep517VirtualEnvPackager | None = None
 
-    @staticmethod
-    def id() -> str:  # noqa: A003
-        return "virtualenv-cmd-builder"
-
     def register_config(self) -> None:
         super().register_config()
         root = self.core["toxinidir"]
@@ -112,11 +104,10 @@ class VirtualEnvCmdBuilder(PythonPackageToxEnv, VirtualEnv):
             package: Package = WheelPackage(path, deps)
         else:  # must be source distribution
             work_dir = self.env_tmp_dir / "sdist-extract"
-            if work_dir.exists():  # pragma: no branch
-                shutil.rmtree(work_dir)  # pragma: no cover
-            work_dir.mkdir()
+            if not work_dir.exists():  # pragma: no branch
+                work_dir.mkdir()
             with tarfile.open(str(path), "r:gz") as tar:
-                tar.extractall(path=str(work_dir))
+                tar.extractall(path=str(work_dir))  # noqa: S202
             # the register run env is guaranteed to be called before this
             assert self._sdist_meta_tox_env is not None  # noqa: S101
             with self._sdist_meta_tox_env.display_context(self._has_display_suspended):
@@ -137,6 +128,12 @@ class VirtualEnvCmdBuilder(PythonPackageToxEnv, VirtualEnv):
             yield self._sdist_meta_tox_env
 
 
+class VirtualEnvCmdBuilder(VenvCmdBuilder, VirtualEnv):
+    @staticmethod
+    def id() -> str:
+        return "virtualenv-cmd-builder"
+
+
 class WheelDistribution(Distribution):  # cannot subclass has type Any
     def __init__(self, wheel: Path) -> None:
         self._wheel = wheel
@@ -171,3 +168,9 @@ class WheelDistribution(Distribution):  # cannot subclass has type Any
 @impl
 def tox_register_tox_env(register: ToxEnvRegister) -> None:
     register.add_package_env(VirtualEnvCmdBuilder)
+
+
+__all__ = [
+    "VenvCmdBuilder",
+    "VirtualEnvCmdBuilder",
+]
