@@ -1,11 +1,13 @@
 from __future__ import annotations
 
 from configparser import ConfigParser
-from pathlib import Path
-from typing import Callable
+from typing import TYPE_CHECKING, Callable
 
 import pytest
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
 
 @pytest.fixture()
 def mk_ini_conf(tmp_path: Path) -> Callable[[str], ConfigParser]:
