@@ -1,17 +1,19 @@
 from __future__ import annotations
 
 from pathlib import Path
-from typing import Callable
+from typing import TYPE_CHECKING, Callable
 
 import pytest
 
-from tests.config.loader.ini.replace.conftest import ReplaceOne
-from tests.conftest import ToxIniCreator
 from tox.config.loader.ini.replace import MAX_REPLACE_DEPTH
 from tox.config.sets import ConfigSet
-from tox.pytest import LogCaptureFixture
 from tox.report import HandledError
 
+if TYPE_CHECKING:
+    from tests.config.loader.ini.replace.conftest import ReplaceOne
+    from tests.conftest import ToxIniCreator
+    from tox.pytest import LogCaptureFixture
+
 EnvConfigCreator = Callable[[str], ConfigSet]
 
 
@@ -19,8 +21,7 @@ EnvConfigCreator = Callable[[str], ConfigSet]
 def example(tox_ini_conf: ToxIniCreator) -> EnvConfigCreator:
     def func(conf: str) -> ConfigSet:
         config = tox_ini_conf(f"""[tox]\nenv_list = a\n[testenv]\n{conf}\n""")
-        env_config = config.get_env("a")
-        return env_config
+        return config.get_env("a")
 
     return func
 
