@@ -479,7 +479,7 @@ def test_parsed_requirement_repr_no_opt(tmp_path: Path) -> None:
 
 @pytest.mark.parametrize("flag", ["-r", "--requirement", "-c", "--constraint"])
 def test_req_over_http(tmp_path: Path, flag: str, mocker: MockerFixture) -> None:
-    is_constraint = flag in ("-c", "--constraint")
+    is_constraint = flag in {"-c", "--constraint"}
     url_open = mocker.patch("tox.tox_env.python.pip.req.file.urlopen", autospec=True)
     url_open.return_value.__enter__.return_value = BytesIO(b"-i i\na")
     requirements_txt = tmp_path / "req.txt"
